cmoncrawl.processor.pipeline.streamer.StreamerDummy
===================================================

.. currentmodule:: cmoncrawl.processor.pipeline.streamer

.. autoclass:: StreamerDummy

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree:

   
      ~StreamerDummy.__init__
      ~StreamerDummy.clean_up
      ~StreamerDummy.stream
   
   

   
   
   